CREATE OR REPLACE TYPE Personne_type AS OBJECT (
    nom VARCHAR2(30),
    prenom VARCHAR2(30),
    daten DATE,
    sexe VARCHAR2(1)
) NOT FINAL;
/
CREATE OR REPLACE TYPE Etudiant_type UNDER Personne_type (
    ine VARCHAR2(50)
) ;
/
CREATE OR REPLACE TYPE Enseignant_type UNDER Personne_type (
    matricule VARCHAR2(50)
);
/
CREATE OR REPLACE TYPE Domaine_type AS OBJECT (
    id_domaine VARCHAR2(2)
);
/
CREATE OR REPLACE TYPE Competence_type AS OBJECT (
    description VARCHAR2(300),
    domaine_id REF Domaine_type
);
/
CREATE OR REPLACE TYPE Aptitude_type AS OBJECT (
    intitule VARCHAR2(2),
    description VARCHAR2(200),
    competence_id REF Competence_type
);
/
CREATE OR REPLACE TYPE Enseignants_list_type AS TABLE OF REF Enseignant_type;
/
CREATE OR REPLACE TYPE Etudiants_list_type AS TABLE OF REF Etudiant_type;
/
CREATE OR REPLACE TYPE Ue_type AS OBJECT (
    intitule VARCHAR2(50),
    enseignants Enseignants_list_type,
    etudiant Etudiants_list_type
);
/
CREATE OR REPLACE TYPE Aptitude_list_type AS TABLE OF REF Aptitude_type;
/
CREATE OR REPLACE TYPE Evaluation_type AS OBJECT (
    ue REF Ue_type,
    aptitudes Aptitude_list_type
);
/
-- Creation des tables --

CREATE TABLE Etudiant OF Etudiant_type (UNIQUE (ine));
CREATE TABLE Enseignant OF Enseignant_type (UNIQUE (matricule));
CREATE TABLE Domaine OF Domaine_type (UNIQUE ( id_domaine));
CREATE TABLE Competence OF Competence_type;
CREATE  TABLE Aptitude OF Aptitude_type ( UNIQUE (intitule));
CREATE TABLE Ue OF Ue_type NESTED TABLE enseignants STORE AS Ue_Enseignants NESTED TABLE etudiant STORE AS Ue_Etudiants;
CREATE TABLE Evaluation OF Evaluation_type
    NESTED TABLE aptitudes STORE AS Evaluation_Aptitudes;

--Insertion des données--
INSERT INTO Etudiant (ine,nom, prenom, daten, sexe) VALUES ('JOLP558','Balde', 'Aziz', TO_DATE('22-02-2000', 'DD-MM-YYYY'), 'M');

INSERT INTO Etudiant (ine,nom, prenom, daten, sexe) VALUES ('HKBLV10','Bouzid', 'Katia', TO_DATE('01-06-2000', 'DD-MM-YYYY'), 'F');
INSERT INTO Etudiant (ine,nom, prenom, daten, sexe) VALUES ('HVRN233','Bennabi', 'Leila', TO_DATE('16-09-2000', 'DD-MM-YYYY'), 'M');
INSERT INTO Enseignant (matricule,nom, prenom, daten, sexe) VALUES ('AMT333','Laurent', 'Amanton', TO_DATE('31-01-1970', 'DD-MM-YYYY'), 'M');
INSERT INTO Enseignant (matricule,nom, prenom, daten, sexe) VALUES ('BLV255','Balev', 'Stefan', TO_DATE('13-12-1974', 'DD-MM-YYYY'), 'M');
INSERT INTO Enseignant (matricule,nom, prenom, daten, sexe) VALUES ('SAL698','Salvandar', 'Eric', TO_DATE('08-07-1960', 'DD-MM-YYYY'), 'M');

commit;
INSERT INTO Domaine (id_domaine) VALUES ('D1');
INSERT INTO Domaine (id_domaine) VALUES ('D2');
INSERT INTO Domaine (id_domaine) VALUES ('D3');
INSERT INTO Domaine (id_domaine) VALUES ('D4');
INSERT INTO Domaine (id_domaine) VALUES ('D5');
INSERT INTO Domaine (id_domaine) VALUES ('D6');

COMMIT ;

INSERT INTO Competence (description, domaine_id)
    VALUES ('C1', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1'));
INSERT INTO Competence (description, domaine_id)
    VALUES ('C1', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D2'));
INSERT INTO Competence (description, domaine_id)
    VALUES ('C1', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D3'));
INSERT INTO Competence (description, domaine_id)
    VALUES ('C2', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1'));
INSERT INTO Competence (description, domaine_id)
    VALUES ('C2', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D2'));
INSERT INTO Competence (description, domaine_id)
    VALUES ('C2', (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D3'));

INSERT INTO Aptitude (intitule, description, competence_id)
VALUES ('A1', 'Tirer parti des atouts de l-objet', (SELECT REF(com) FROM Competence com  WHERE com.description = 'C2' AND
        com.domaine_id = (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1')));

INSERT INTO Aptitude (intitule, description, competence_id)
VALUES ('A2', 'Traduire un modèle en code RO', (SELECT REF(com) FROM Competence com  WHERE com.description = 'C2' AND
        com.domaine_id = (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1')));

INSERT INTO Aptitude (intitule, description, competence_id)
VALUES ('A3','Savoir utilisé DataGrip', (SELECT REF(com) FROM Competence com  WHERE com.description = 'C1' AND
        com.domaine_id = (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1')));

INSERT INTO Aptitude (intitule, description, competence_id)
VALUES ('A4','Savoir connecter DataGrip', (SELECT REF(com) FROM Competence com  WHERE com.description = 'C1' AND
        com.domaine_id = (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1')));

INSERT INTO Aptitude (intitule, description, competence_id)
VALUES ('A6','Configurer un projet GraphStream', (SELECT REF(com) FROM Competence com  WHERE com.description = 'C1' AND
        com.domaine_id = (SELECT REF(dom) FROM Domaine dom WHERE dom.id_domaine = 'D1')));

INSERT INTO Ue (intitule, enseignants, etudiant)
VALUES ('M1_BDA', Enseignants_list_type(
        (SELECT REF(e) FROM Enseignant e WHERE e.matricule = 'AMT333')
    ),
        Etudiants_list_type(
        (SELECT REF(e) FROM Etudiant e WHERE e.ine = 'HKBLV10')
    )
);

INSERT INTO Ue (intitule, enseignants, etudiant)
VALUES ('L3_ENG', Enseignants_list_type(
        (SELECT REF(e) FROM Enseignant e WHERE e.matricule = 'AMT333')
    ),
        Etudiants_list_type(
        (SELECT REF(e) FROM Etudiant e WHERE e.ine = 'HKBLV10')
    )
);

INSERT INTO Ue (intitule, enseignants, etudiant)
VALUES ('M1_GRA', Enseignants_list_type(
        (SELECT REF(e) FROM Enseignant e WHERE e.matricule = 'BLV255')
    ),
        Etudiants_list_type(
        (SELECT REF(e) FROM Etudiant e WHERE e.ine = 'HKBLV10'),
        (SELECT REF(e) FROM Etudiant e WHERE e.ine = 'JOLP558')
    )
);

INSERT INTO Evaluation (ue, aptitudes)
VALUES ((SELECT REF(u) FROM Ue u WHERE u.intitule = 'M1_BDA'),
    Aptitude_list_type(
        (SELECT REF(a) FROM Aptitude a WHERE a.intitule = 'A1')
    )
);

INSERT INTO Evaluation (ue, aptitudes)
VALUES ((SELECT REF(u) FROM Ue u WHERE u.intitule = 'M1_BDA'),
    Aptitude_list_type(
        (SELECT REF(a) FROM Aptitude a WHERE a.intitule = 'A2')
    )
);

INSERT INTO Evaluation (ue, aptitudes)
VALUES ((SELECT REF(u) FROM Ue u WHERE u.intitule = 'M1_GRA'),
    Aptitude_list_type(
        (SELECT REF(a) FROM Aptitude a WHERE a.intitule = 'A6')
    )
);
COMMIT;

-- requete de selection --

--cette requette permet de selectionné tous les aptitudes du domaine D1
SELECT a.description FROM Aptitude a WHERE a.competence_id.domaine_id.id_domaine = 'D1';

-- cette requete des ue tenu par M. Balev
SELECT u.intitule
    FROM Ue u, TABLE(u.enseignants) e
    WHERE e.COLUMN_VALUE.matricule = 'BLV255';


-- cette requete qui permet de trouver le nombre d'evaluation par UE
SELECT e.ue.intitule, COUNT(*) as "Nombre d'évaluations"
FROM Evaluation e
GROUP BY e.ue.intitule;



